@@ -34,7 +34,8 @@ if __name__ == "__main__":
     sys.path.insert(0, os.path.join(os.path.dirname(__file__), "..", "src"))
 
 from nwp500.api_client import NavienAPIClient
-from nwp500.auth import AuthenticationError, NavienAuthClient
+from nwp500.auth import NavienAuthClient
+from nwp500.exceptions import AuthenticationError
 from nwp500.models import DeviceStatus
 from nwp500.mqtt_client import NavienMqttClient
 
